package com.persagy.adm.server.custom.controller;

import cn.hutool.core.util.StrUtil;
import com.persagy.adm.server.custom.client.ImageServiceClient;
import com.persagy.adm.server.custom.common.AdmRequest;
import com.persagy.adm.server.custom.common.AdmResult;
import com.persagy.adm.server.custom.datatx.DataTxHandler;
import com.persagy.adm.server.custom.entity.ConfigData;
import com.persagy.adm.server.custom.entity.Dict;
import com.persagy.adm.server.custom.entity.DownLoadData;
import com.persagy.adm.server.custom.entity.UploadRtn;
import com.persagy.adm.server.custom.service.ISyncApp;
import com.persagy.adm.server.custom.service.ServiceUtil;
import feign.Response;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;

/**
 * APP离线数据服务
 */
@RestController
@RequestMapping("/adm")
public class AppController {

	@Autowired
	@Qualifier(ServiceUtil.SYNC_APP_IMPL)
	private ISyncApp syncApp;

	@Autowired
	private DataTxHandler dataTxHandler;

	@RequestMapping("/clientId")
	public AdmResult<Map<String, Object>> clientId(@RequestBody AdmRequest req){
		HashMap<String, Object> rtn = new HashMap<>();
		rtn.put("clientId", syncApp.getClientId(req.getUserId()));
		return AdmResult.success(rtn);
	}

	@RequestMapping("/dict")
	public AdmResult<Dict> dict(@RequestBody AdmRequest req){
		return AdmResult.success(syncApp.downloadDict(req.getGroupCode(), req.getProjectId(), req.getUserId()));
	}

	@RequestMapping("/config")
	public AdmResult<ConfigData> config(@RequestBody AdmRequest req){
		return AdmResult.success(syncApp.downloadConfig(req.getGroupCode(), req.getProjectId(), req.getUserId()));
	}

	@RequestMapping("/frame")
	public AdmResult<Map<String, Object>> frame(@RequestBody AdmRequest req){
		return AdmResult.success(syncApp.downloadFrameData(req.getGroupCode(), req.getProjectId(), req.getUserId()));
	}

	@RequestMapping("/download")
	public AdmResult<DownLoadData> download(@RequestBody AdmRequest req){
		DownLoadData data;
		if(StrUtil.isNotBlank(req.getBuildingId())) {
			data = syncApp.downloadBuildingData(req.getGroupCode(), req.getProjectId(), req.getUserId(), req.getClientId(), req.getBuildingId(), req.getBdtpDownloadTs(), req.getAdmDownloadTs());
		} else
			data = syncApp.downloadProjectData(req.getGroupCode(), req.getProjectId(), req.getUserId(), req.getClientId(), req.getBdtpDownloadTs(), req.getAdmDownloadTs());
		return AdmResult.success(data);
	}


	@RequestMapping("/upload")
	public AdmResult<UploadRtn> upload(HttpServletRequest request){
		AdmRequest admRequest = dataTxHandler.handleRequest(request);
		return AdmResult.success(syncApp.uploadData(admRequest.getUploadData(), admRequest.getGroupCode(), admRequest.getProjectId(), admRequest.getUserId(), admRequest.getClientId()));
	}

}
